<?php
/**
 * This is the child theme for PressBook theme.
 *
 * (See https://developer.wordpress.org/themes/advanced-topics/child-themes/#how-to-create-a-child-theme)
 *
 * @package PressBook_Grid_Dark
 */

defined( 'ABSPATH' ) || die();

define( 'PRESSBOOK_GRID_DARK_VERSION', '1.0.6' );

/**
 * Load child theme text domain.
 */
function pressbook_grid_dark_setup() {
	load_child_theme_textdomain( 'pressbook-grid-dark', get_stylesheet_directory() . '/languages' );
}
add_action( 'after_setup_theme', 'pressbook_grid_dark_setup', 11 );

/**
 * Load child theme services.
 *
 * @param  array $services Parent theme services.
 * @return array
 */
function pressbook_grid_dark_services( $services ) {
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-grid-dark-cssrules.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-grid-dark-scripts.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-grid-dark-editor.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-grid-dark-primarynavbar.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-grid-dark-related-posts.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-grid-dark-options.php';
	require get_stylesheet_directory() . '/inc/classes/class-pressbook-grid-dark-jetpack.php';

	foreach ( $services as $key => $service ) {
		if ( 'PressBook\Editor' === $service ) {
			$services[ $key ] = PressBook_Grid_Dark_Editor::class;
		} elseif ( 'PressBook\Scripts' === $service ) {
			$services[ $key ] = PressBook_Grid_Dark_Scripts::class;
		} elseif ( 'PressBook\Jetpack' === $service ) {
			$services[ $key ] = PressBook_Grid_Dark_Jetpack::class;
		}
	}

	array_push( $services, PressBook_Grid_Dark_PrimaryNavbar::class );
	array_push( $services, PressBook_Grid_Dark_Related_Posts::class );
	array_push( $services, PressBook_Grid_Dark_Options::class );

	return $services;
}
add_filter( 'pressbook_services', 'pressbook_grid_dark_services' );

/**
 * Change default background args.
 *
 * @param  array $args Custom background args.
 * @return array
 */
function pressbook_grid_dark_custom_background_args( $args ) {
	return array(
		'default-color' => '1e1e1e',
		'default-image' => '',
	);
}
add_filter( 'pressbook_custom_background_args', 'pressbook_grid_dark_custom_background_args' );

/**
 * Change default styles.
 *
 * @param  array $styles Default sttyles.
 * @return array
 */
function pressbook_grid_dark_default_styles( $styles ) {
	$styles['top_navbar_bg_color_1']         = 'rgba(6,9,44,0.95)';
	$styles['top_navbar_bg_color_2']         = '#3e4ee6';
	$styles['primary_navbar_bg_color']       = 'rgba(0,0,0,0.9)';
	$styles['primary_navbar_hover_bg_color'] = 'rgba(57,73,229,0.95)';
	$styles['header_bg_color']               = 'rgba(10,10,10,0.9)';
	$styles['site_title_color']              = '#ffffff';
	$styles['tagline_color']                 = '#a2a2a2';
	$styles['button_bg_color_1']             = '#4252e6';
	$styles['button_bg_color_2']             = 'rgba(49,66,228,0.95)';
	$styles['side_widget_border_color']      = 'rgba(0,0,0,0.95)';
	$styles['footer_bg_color']               = 'rgba(0,0,0,0.93)';
	$styles['footer_credit_link_color']      = '#7682eb';

	return $styles;
}
add_filter( 'pressbook_default_styles', 'pressbook_grid_dark_default_styles' );

/**
 * Change welcome page title.
 *
 * @param  string $page_title Welcome page title.
 * @return string
 */
function pressbook_grid_dark_welcome_page_title( $page_title ) {
	return esc_html_x( 'PressBook Grid Dark', 'page title', 'pressbook-grid-dark' );
}
add_filter( 'pressbook_welcome_page_title', 'pressbook_grid_dark_welcome_page_title' );

/**
 * Change welcome menu title.
 *
 * @param  string $menu_title Welcome menu title.
 * @return string
 */
function pressbook_grid_dark_welcome_menu_title( $menu_title ) {
	return esc_html_x( 'PressBook Grid', 'menu title', 'pressbook-grid-dark' );
}
add_filter( 'pressbook_welcome_menu_title', 'pressbook_grid_dark_welcome_menu_title' );

/**
 * Recommended plugins.
 */
require get_stylesheet_directory() . '/inc/recommended-plugins.php';
